{% load sri %}
<!-- Start Bootstrap + jQuery js from aa-gdpr -->
{% sri_static "aagdpr/ajax/libs/jquery/3.7.1/jquery.min.js" %}
{% sri_static "aagdpr/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js" %}
<!-- End Bootstrap + jQuery js from aa-gdpr -->
