{% load aa_i18n %}
{% load i18n %}
{% load sri %}

<!-- Start Moment.js from aa-gdpr -->
{% sri_static "aagdpr/ajax/libs/moment.js/2.29.4/moment.min.js" %}

{% if locale and LANGUAGE_CODE != 'en' %}
    <!-- Moment.JS Not EN-en ({{ LANGUAGE_CODE }}) -->
    {% get_relative_momentjs_language_path LANGUAGE_CODE as MOMENTJS_LANG_PATH %}

    {% sri_static MOMENTJS_LANG_PATH %}
{% endif %}
<!-- End Moment.js from aa-gdpr -->
