{% load sri %}
<!-- Start jQuery-DateTimePicker CSS from aa-gdpr -->
{% sri_static "aagdpr/ajax/libs/jquery-datetimepicker/2.5.20/jquery.datetimepicker.min.css" %}
<!-- End jQuery-DateTimePicker CSS from aa-gdpr -->
