{% load sri %}
<!-- Start Datatables-js from aa-gdpr -->
{% sri_static "aagdpr/ajax/libs/datatables.net/1.13.7/js/jquery.dataTables.min.js" %}
{% sri_static "aagdpr/ajax/libs/datatables.net/1.13.7/js/dataTables.bootstrap5.min.js" %}
<!-- End Datatables-js from aa-gdpr -->
