{% load sri %}
<!-- Start jQuery-DateTimePicker JS from aa-gdpr -->
{% sri_static "aagdpr/ajax/libs/jquery-datetimepicker/2.5.20/jquery.datetimepicker.full.min.js" %}
<!-- End jQuery-DateTimePicker JS from aa-gdpr -->
